@@ -1,5 +1,5 @@
 package Log::Log4perl::Shortcuts ;
-$Log::Log4perl::Shortcuts::VERSION = '0.010';
+$Log::Log4perl::Shortcuts::VERSION = '0.011';
 use 5.10.0;
 use Carp;
 use Log::Log4perl;
@@ -11,13 +11,13 @@ use Data::Dumper qw(Dumper);
 
 require Exporter;
 @ISA = Exporter;
-@EXPORT_OK = qw(logc logt logd logi logw loge logf change_config_file set_log_level);
-%EXPORT_TAGS = ( all => [qw(logc logt logd logi logw loge logf change_config_file set_log_level)] );
+@EXPORT_OK = qw(logc logt logd logi logw loge logf set_log_config set_log_level);
+%EXPORT_TAGS = ( all => [qw(logc logt logd logi logw loge logf set_log_config set_log_level)] );
 Exporter::export_ok_tags('all');
 
 my $package = __PACKAGE__;
 $package =~ s/::/-/g;
-my $config_dir = path(File::UserConfig->new(dist => $package)->configdir, 'config');
+my $config_dir = path(File::UserConfig->new(dist => $package)->configdir, 'log_config');
 
 my $default_config_file = path($config_dir, 'default.cfg');
 
@@ -31,13 +31,22 @@ my $log_level = $TRACE;
 
 ### Public methods ###
 
-sub change_config_file {
+sub set_log_config {
   my $new_config = shift;
+  my $module = shift;
+
+  my $temp_config_dir;
+  if ($module) {
+    $module =~ s/::/-/g;
+    $temp_config_dir = path(File::UserConfig->new(dist => $module)->configdir, 'log_config');
+  } else {
+    $temp_config_dir = $config_dir;
+  }
+
+  my $path = path($temp_config_dir, $new_config);
 
-  my $path = path($config_dir, $new_config);
   if (!$path->is_file) {
-    carp ("Configuration file $path->canonpath does not exist. Configuration file unchanged."
-      . " Place your custom log configuration file in $config_dir.");
+    carp ("Configuration file $path->canonpath does not exist. Configuration file unchanged.");
   } else {
     Log::Log4perl->init($path->canonpath);
     return 'success';
@@ -99,27 +108,46 @@ sub logw {
 sub loge {
   my $msg = shift;
 
-  my $log = _get_logger(shift);;
+  my $log = '';
+  my $options = {};
+  my $next_arg = shift;
+  if (ref $next_arg) {
+    my $options = shift;
+  } else {
+    $log = _get_logger($next_arg);;
+  }
+
   return unless $log->is_error;
 
-  $msg = sprintf("%-80s %s\n", $msg, [caller(0)]->[0] . ": " . [caller(0)]->[2]);
-  $msg .= '        ' . _get_callers();
-  chomp $msg;
-  chomp $msg;
-
+  $msg = sprintf("%-80s %s\n", $msg, [caller(0)]->[0] . ": line " . [caller(0)]->[2]);
+  if ($options->{show_callers}) {
+    $msg .= '        ' . _get_callers();
+    chomp $msg;
+    chomp $msg;
+  }
   $log->error_warn($msg);
 }
 
 sub logf {
   my $msg = shift;
 
-  my $log = _get_logger(shift);;
+  my $log = '';
+  my $options = {};
+  my $next_arg = shift;
+  if (ref $next_arg) {
+    my $options = shift;
+  } else {
+    $log = _get_logger($next_arg);;
+  }
+
   return unless $log->is_fatal;
 
-  $msg = sprintf("%-80s %s\n", $msg, [caller(0)]->[0] . ": " . [caller(0)]->[2]);
-  $msg .= '        ' . _get_callers();
-  chomp $msg;
-  chomp $msg;
+  $msg = sprintf("%-80s %s\n", $msg, [caller(0)]->[0] . ": line " . [caller(0)]->[2]);
+  if ($options->{show_callers}) {
+    $msg .= '        ' . _get_callers();
+    chomp $msg;
+    chomp $msg;
+  }
 
   $log->logdie($msg);
 }
@@ -160,7 +188,7 @@ Log::Log4perl::Shortcuts - shortcut functions to make log4perl even easier
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 OVERVIEW
 
@@ -201,6 +229,10 @@ The B<$category> arguments, if supplied, are appended to the name of the calling
 package where the log command was invoked. For example, if C<logi('Info log entry', 'my_category')>
 is called from package C<Foo::Bar>, the log entry will be made with the category:
 
+The B<$options> arguments, if avaiable, supply addition options to the C<loge>
+and C<logf> functions. If C< { show_callers =E<gt> 1 } > is supplied, a stack trace
+will be printed out below the error or fatal message.
+
   Foo::Bar.my_category
 
 =head1 Functions
@@ -225,11 +257,11 @@ Prints a message to the I<info> logger when the log level is set to B<INFO> or a
 
 Prints a message to the I<warn> logger when the log level is set to B<WARN> or above.
 
-=head2 loge ($msg, [$category])
+=head2 loge ($msg, [$category], [{ $options => value, ... }])
 
 Prints a message to the I<error> logger when the log level is set to B<ERROR> or above.
 
-=head2 logf ($msg, [$category])
+=head2 logf ($msg, [$category], [{ $options => value, ... }])
 
 Prints a message to the I<fatal> logger when the log level is set to B<FATAL> or above.
 
@@ -240,7 +272,7 @@ Prints a message to the I<fatal> logger when the log level is set to B<FATAL> or
 Prints call stack when log level is set to B<TRACE> or above. Note that no
 message argument is used by this function.
 
-=head2 change_config_file ($filename)
+=head2 set_log_config ($filename)
 
 Changes the log configuration file which must be placed in the C<~/perl/log_config> directory.
 
@@ -251,7 +283,7 @@ Change the log level. Should be one of 'trace', 'debug', 'info', 'warn', 'error'
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Place any custom log configuration files you'd like to use in C<~/perl/log_config> and use the
-C<change_config_file> function to switch to it.
+C<set_log_config> function to switch to it.
 
 =head1 REQUIRES
 
